package models

import (
	"math/big"

	"github.com/ethereum/go-ethereum/common"
)

type UserInfo struct {
	Id               int64
	Addr             string
	Direct           int
	Indirect         int
	TeamMembers      string
	AvailableClaim   float64 `xorm:"Decimal"`
	TotalClaimed     float64 `xorm:"Decimal"`
	AvailableReinput float64 `xorm:"Decimal"`
	TotalReinputed   float64 `xorm:"Decimal"`
	State            int
	OpTime           string
}

type UserTxs struct {
	Id     int64
	Addr   string
	Hash   string
	OpTime string
}

type AddrBill struct {
	Id         int64
	Addr       string
	Amount     float64 `xorm:"Decimal"`
	BillType   int
	CreateTime string
}

type UserAddr struct {
	Addr         string `xorm:"pk"`
	IdFlag       int
	Pid          int
	RealPid      int
	PidFlag      string
	People       int
	Level        int
	RemovePeople int
	TeamBoss     int
	BadTime      string
	Msg          string
	LockAmount1  float64 `xorm:"Decimal"`
	LockAmount2  float64 `xorm:"Decimal"`
	Profit1      float64 `xorm:"Decimal"`
	Profit2      float64 `xorm:"Decimal"`
	Profit3      float64 `xorm:"Decimal"`
	Profit4      float64 `xorm:"Decimal"`
	Amount       float64 `xorm:"Decimal"`
	Price        float64 `xorm:"Decimal"`
	UseAmount    float64 `xorm:"Decimal"`
	AmountLv     float64 `xorm:"Decimal"`
	Hash         string
	Block        int64
	CreateTime   string
}

type CommonInfo struct {
	Id           int64
	Amount       float64 `xorm:"Decimal"`
	SupplyAmount float64 `xorm:"Decimal"`
	SupplyTime   string
}

type SuccessBill struct {
	Id         int64
	Addr       string
	Amount     float64 `xorm:"Decimal"`
	Status     int
	Block      int64
	Hash       string
	FromAddr   string
	Ty         int
	CreateTime string
}

type WithdrawalBill struct {
	Id          int64
	Addr        string
	Amount      float64 `xorm:"Decimal"`
	Status      int
	CreateBlock int64
	SucBlock    int64
	Hash        string
	CreateTime  string
}

type TeamUserInfo struct {
	Addr       string
	People     int
	NftNum     int
	CreateTime string
}

type Ihot struct {
	User     common.Address
	Referrer common.Address
	Amount   *big.Int
	Price    *big.Int
}

type Withdraw struct {
	User   common.Address
	Amount *big.Int
}
